@@ -6,9 +6,7 @@ cd /io
 # List python versions
 ls /opt/python
 
-if [ $PYTHON_VERSION == "3.8" ]; then
-    PYBIN="/opt/python/cp38-cp38/bin"
-elif [ $PYTHON_VERSION == "3.9" ]; then
+if [ $PYTHON_VERSION == "3.9" ]; then
     PYBIN="/opt/python/cp39-cp39/bin"
 elif [ $PYTHON_VERSION == "3.10" ]; then
     PYBIN="/opt/python/cp310-cp310/bin"
@@ -24,8 +22,7 @@ PYVER=${PYTHON_VERSION//.}
 
 # Install package and test
 ${PYBIN}/pip install ./dist/rawpy*cp${PYVER}*manylinux*${PYTHON_ARCH}*.whl
-
-${PYBIN}/pip install -r dev-requirements.txt
+${PYBIN}/pip install -r dev-requirements.txt "numpy==${NUMPY_VERSION}"
 
 mkdir tmp_for_test
 pushd tmp_for_test
